CanSettingsBitrate

Enum CanSettingsBitrate 

pub enum CanSettingsBitrate {
    Standard {
        bitrate: u32,
        sample_point: Option<f32>,
    },
    Custom {
        tq: u8,
        prop_seg: u8,
        phase_seg1: u8,
        phase_seg2: u8,
        sjw: Option<u8>,
    },
}
Настройка скорости передачи CAN

Variants



Standard

Обычное задание скорости

Fields

bitrate: u32

CAN interface’s bit rate (bps)

sample_point: Option<f32>

Point in time period where the bus is read to get the current bit level



Custom

Пользовательская настройка скорости

Fields

tq: u8

Time Quantum (1 TQ = 1 Clock tick)

prop_seg: u8

Compensates the propagation of physical delays between nodes

phase_seg1: u8

Used to compensate errors between signal edges and adjust the length of the bit

phase_seg2: u8

Used to compensate errors between signal edges and adjust the length of the bit

sjw: Option<u8>

Synchronization jump width, that’s the maximum time by which the bit sampling period might be delayed or shortened during each cycle