pub enum CanSettingsDbitrate {
None,
Standard {
dbitrate: u32,
dsample_point: Option<f32>,
tdcv: Option<u8>,
tdco: Option<u8>,
tdcf: Option<u8>,
},
Custom {
dtq: u8,
dprop_seg: u8,
dphase_seg1: u8,
dphase_seg2: u8,
dsjw: Option<u8>,
tdcv: Option<u8>,
tdco: Option<u8>,
tdcf: Option<u8>,
},
}Expand description
Настройка скорости передачи CAN-FD
Variants
None
Используется классический CAN
Standard
Обычное задание скорости
Fields
dbitrate: u32Data bit rate (used in CAN FD, which supports different bit rates for the arbitration phase and the data/payload phase)
dsample_point: Option<f32>Data Time Quantum (used in CAN FD)
tdcv: Option<u8>Transmitter Delay Compensation Value (used in CAN FD)
tdco: Option<u8>Transmitter Delay Compensation Offset (used in CAN FD)
tdcf: Option<u8>Transmitter Delay Compensation Filter windows value (used in CAN FD)
Custom
Пользовательская настройка скорости
Fields
dtq: u8Data Time Quantum (used in CAN FD)
dprop_seg: u8Compensates the propagation of physical delays between nodes
dphase_seg1: u8Used to compensate errors between signal edges and adjust the length of the bit
dphase_seg2: u8Used to compensate errors between signal edges and adjust the length of the bit
dsjw: Option<u8>Synchronization jump width, that’s the maximum time by which the bit sampling period might be delayed or shortened during each cycle
tdcv: Option<u8>Transmitter Delay Compensation Value (used in CAN FD)
tdco: Option<u8>Transmitter Delay Compensation Offset (used in CAN FD)
tdcf: Option<u8>Transmitter Delay Compensation Filter windows value (used in CAN FD)