pub struct CanSettings {Show 13 fields
pub bitrate: CanSettingsBitrate,
pub dbitrate: CanSettingsDbitrate,
pub mode_loopback: bool,
pub mode_listen_only: bool,
pub mode_triple_sampling: bool,
pub mode_one_shot: bool,
pub mode_berr_reporting: bool,
pub mode_fd: bool,
pub mode_presume_ack: bool,
pub mode_fd_non_iso: bool,
pub mode_cc_len8_dlc: bool,
pub mode_tdcv_mode: bool,
pub restart_ms: Option<u32>,
}Expand description
Конфигурация CAN-протокола
Fields
bitrate: CanSettingsBitrateНастройка скорости CAN
dbitrate: CanSettingsDbitrateНастройка скорости CAN-FD
mode_loopback: boolUsed specially when running more than one application on the same node (host)
mode_listen_only: boolOnly listen for frames on the bus (no sending)
mode_triple_sampling: boolMake 3 samples instead of 1 during the bit time (on the 2 TQs before the Sample Point)
mode_one_shot: boolJust send the CAN message one time (skip retransmission in case of error)
mode_berr_reporting: boolEnable/Disable Bit Error reporting
mode_fd: boolCAN-FD протокол
mode_presume_ack: boolWhen enabled, acknowledgement absence is ignored
mode_fd_non_iso: boolEnable non-ISO CAN FD (this is the first specification of CAN FD, called CAN FD 1.0 and it’s not compatible with ISO CAN FD)
mode_cc_len8_dlc: boolDLC remaining seven values from 9 to 15 used for CAN FD should be set to 8 for standard CAN.
mode_tdcv_mode: boolTransmitter Delay Compensation Value mode (automatic, manual or disabled - used in CAN FD)
restart_ms: Option<u32>Automatic restart delay time, the time to wait before restart the CAN controller in case of a bus-off condition (a CAN node becomes Bus-Off when the the counter for transmission errors becomes greater or equal to 256, so the node is deactivated)